#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-5a7SIFV0Eup1vomUvOxkRC
key:                  gitit-0.16-5a7SIFV0Eup1vomUvOxkRC
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  011446d29fdd719ec771352ba1887028
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-5a7SIFV0Eup1vomUvOxkRC
depends:
    HStringTemplate-0.8.8-DLgsiFanfBT4Ih0leZ0kyd
    HTTP-4000.5.0-9GzGZ9HPLLhLONhXAoMTHF
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1
    base64-bytestring-1.2.1.0-HSSC8ZpQ1EiHU6Qv1r7ZrY
    blaze-html-0.9.2.0-EgbbWPmo3205UQl3AObEBN bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-2sWGZckRwCV3STeHrvFtcV
    feed-1.3.2.1-3m7z9E7oCRrJwJhhoepKAg filepath-1.4.300.1
    filestore-0.6.5.1-7UvzuFq6r2NPIwG0CgA3G ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-9E5f0fbG7mmCD3QgLizfpc
    hoauth2-2.14.0-4S7QMS0IvY2GFt8nuQmcOp
    hslogger-1.3.2.0-GAr2nr39v5u7MT76n3CViS
    http-client-tls-0.3.6.4-HN3tMmJV0pX8jUBu7FQeO5
    http-conduit-2.3.9.1-9jvrxr3X32oD7zCQ7xobvq
    json-0.11-8lNNdGLbGjvAsWhsz0sm7l mtl-2.3.1
    network-3.1.4.0-5wCX3hTprFv2vYcKA8r7kN
    network-bsd-2.8.1.0-29JqBQgR4eVBqfhy9geaz6
    network-uri-2.6.4.2-CsSn6pfoiNDqvqEIqKYSC
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-FdsjiUCJpraEY8r14JIPMN
    pandoc-3.6-6tEwN8P3fxs38wooNnsQhI
    pandoc-types-1.23.1.1-8Liik9ap3oiIlMB4i0obm2 parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-1S1SEs3xtKIgpnjewCuMr
    recaptcha-0.1.0.4-J9tz6o37Ckb14EZiDhnZBU
    safe-0.3.21-5cDqdM4UkK7EDZIzOzgnXr
    skylighting-0.14.5-5tzoaOZuvHKrgAd7Jau4h
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-IWvKvWWONKwAx7053zcTAl
    tagsoup-0.14.8-2XwWq5YTPp4LdOYbDR0bQK
    temporary-1.3-HWoowl2obdSCRTCICKYJCV text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-G75YyvaDUfK81zaTTKDstc
    url-2.1.3-7Kl4E3eXP9D927NfHGnLmQ
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    uuid-1.3.16.1-5nBx1zqzMyABYgSGjQK07L xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-CLbEk2YsfnFYwCxvuWSoO
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-1IwYfzAVorgL9eJmKOwscV
    zlib-0.7.1.0-o5ZrO8tsYqEMdOctKNx4t

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

